.. _pyclaw:

*******
Riemann
*******

This is a one-stop repository for all Clawpack Riemann solvers.  In the past,
many wave propagation Riemann solvers were developed for Clawpack by different
parties.  They are all being collected here.  If you have written a Riemann solver
that is not currently included in the repository, please consider contributing it.
